package com.fms.system.service;

import java.util.List;
import com.fms.system.domain.Brand;

/**
 * 机型系列Service接口
 * 
 * @author Allen
 * @date 2024-05-14
 */
public interface IBrandService 
{
    /**
     * 查询机型系列
     * 
     * @param brandId 机型系列主键
     * @return 机型系列
     */
    public Brand selectBrandByBrandId(Long brandId);

    /**
     * 查询机型系列列表
     * 
     * @param brand 机型系列
     * @return 机型系列集合
     */
    public List<Brand> selectBrandList(Brand brand);

    /**
     * 新增机型系列
     * 
     * @param brand 机型系列
     * @return 结果
     */
    public int insertBrand(Brand brand);

    /**
     * 修改机型系列
     * 
     * @param brand 机型系列
     * @return 结果
     */
    public int updateBrand(Brand brand);

    /**
     * 批量删除机型系列
     * 
     * @param brandIds 需要删除的机型系列主键集合
     * @return 结果
     */
    public int deleteBrandByBrandIds(Long[] brandIds);

    /**
     * 删除机型系列信息
     * 
     * @param brandId 机型系列主键
     * @return 结果
     */
    public int deleteBrandByBrandId(Long brandId);
}
